//------------------------------------------------------------------------------
// Account.h
//
// Copyright (c) 2006 MotiMotion
// All rights reserved.
//
// Author: Michael Rutt (michael@motimotion.com)
//		   http://blogs.motimotion.com/michael
//------------------------------------------------------------------------------

#import "Transaction.h"
#import <Cocoa/Cocoa.h>


//------------------------------------------------------------------------------
// TODO: class description...
//------------------------------------------------------------------------------
@interface Account : NSManagedObject
{
	// Starting index to update the balances
	unsigned startingBalanceUpdateIndex;
	
	/// YES if the date changed on the transaction
	BOOL		dateChanged;
	
	/// YES if the amount changed on the transaction
	BOOL		amountChanged;
	
	/// When a date changes on a transaction, this stores the old date
	/// for purposes of reassigning the transaction ID
	NSDate*		oldTransactionDate;
	
	/// Update the balances automatically or only when told?
	BOOL		updateBalancesAutomatically;
}

//------------------------------------------------------------------------------
// Called whenever 

//------------------------------------------------------------------------------
// Called whenever a new Account is created.  Sets up all the default account
// information and creates an opening balance transaction.
//------------------------------------------------------------------------------
- (void) awakeFromInsert;

//------------------------------------------------------------------------------
// Called whenever an observed key is changed.
//------------------------------------------------------------------------------
/*
- (void) observeValueForKeyPath:(NSString *)keyPath
					   ofObject:(id)object 
						 change:(NSDictionary *)change
						context:(void *)context;
*/
//- (void) updateBalancesForObjects: (NSSet *) objects;

//- (void) updateAllBalances;

//------------------------------------------------------------------------------
// Called by observeValueForKeyPath... whenever the amount of a transaction
// is modified so balance information can be updated for all subsequent
// transactions and the entire account.
//------------------------------------------------------------------------------
//- (void) updateBalancesForObject: (id) object withChange: (NSDictionary *) change;

//------------------------------------------------------------------------------
// Notifies an account that a transaction could be moved based upon a change
// in date, which will affect how the balances are updated for all transactions.
// The account stores the position of the transaction before the move so it
// knows the index that it needs to start at when updating the balances after
// the move.
//------------------------------------------------------------------------------
- (void) transactionDateIsChanging: (Transaction *) transaction;

- (void) transactionAmountIsChanging: (Transaction *) transaction;

////////////////////////////////////////////////////////////////////////////////
/// If the balance date is different from today's date, this calls
/// setTodaysBalanceFromTransactions to set the account balance for today
/// based on its latest transaction list.
////////////////////////////////////////////////////////////////////////////////
- (void) setBalanceForToday;

////////////////////////////////////////////////////////////////////////////////
/// Sets the account balance for today using the date-ordered list of
/// transactions that have been previously sorted.
////////////////////////////////////////////////////////////////////////////////
- (void) setBalanceForTodayFromTransactions: (NSArray*) transactions;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) updateBalances;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) updateBalancesStartingWithID: (unsigned) transactionID;

////////////////////////////////////////////////////////////////////////////////
/// 
////////////////////////////////////////////////////////////////////////////////
- (void) renumberTransactionIDsStartingAtIndex: (unsigned) index
							 balanceDifference: (NSDecimalNumber*) balanceDifference
						  updateAccountBalance: (BOOL) updateBalance;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) assignIDToNewTransaction: (Transaction *) newTransaction;

////////////////////////////////////////////////////////////////////////////////
/// Reassigns an ID to the transaction if necessary and returns the (possibly)
/// new ID of the transaction.  Normally this only reassigns the ID if it
/// detects a change in the date.  Setting forceUpdate to true will update
/// it no matter what.
////////////////////////////////////////////////////////////////////////////////
- (int) reassignIDToTransaction: (Transaction *) existingTransaction
				 updateBalances: (BOOL) update
				    forceUpdate: (BOOL) forceUpdate;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) setUpdateBalancesAutomatically: (BOOL) updateAutomatically;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (BOOL) updateBalancesAutomatically;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (NSString *) longName;

////////////////////////////////////////////////////////////////////////////////
/// Validates the name key to ensure there are no duplicates.
// /////////////////////////////////////////////////////////////////////////////
- (BOOL) validateName: (id *)ioValue error: (NSError **)outError;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (NSComparisonResult) date: (NSDate*) firstDate comparedToDate: (NSDate*) secondDate;

@end
