////////////////////////////////////////////////////////////////////////////////
//  AccountsOutlineView.h
////////////////////////////////////////////////////////////////////////////////
///
/// @brief	Custom outline view for the accounts list in the main window.
///
/// The AccountsOutlineView class is used to defined a custom class for the
/// account list in Prospects.  It contains numerous features to control
/// appearance and behavior of the list.
///
/// Copyright (c) 2006 MotiMotion.
///
/// @author	Michael Rutt
///			<a href="mailto:michael@motimotion.com">michael@motimotion.com</a>
///			<a href="http://www.mikerutt.com">http://www.mikerutt.com</a>
///
////////////////////////////////////////////////////////////////////////////////

#import "MotiGradientOutlineView.h"
#import <Cocoa/Cocoa.h>


@interface AccountsOutlineView : MotiGradientOutlineView
{
	/// The content view will contain the view that matches the currently
	/// selected account
	IBOutlet id contentView;

	/// This is the My Prospects view
	IBOutlet id myProspectsView;
	
	/// This is a binder view
	IBOutlet id binderView;
	
	/// Outlet to the binder controller
	IBOutlet id	binderController;
	
	/// Outlet to the my prospects controller
	IBOutlet id myProspectsController;
	
	/// This is a bank (checking/savings) type view
	IBOutlet id bankAccountView;
	
	/// The column selection menu for the bank account view; this needs to be
	/// adjusted for the account type
	IBOutlet id bankAccountViewColMenu;
	
	/// Supplemental credit card view
	IBOutlet id ccView;
	
	/// Supplemental bank account view
	IBOutlet id bankAccountSupplementalView;
	
	/// Report view
	IBOutlet id reportView;

	/// This is a savings bonds type view
	IBOutlet id savingsBondsAccountView;
	
	/// This is a budget view
	IBOutlet id budgetView;

	/// This is a budget view controller
	IBOutlet id budgetViewController;
	
	/// The document this is associated with
	IBOutlet id document;
	
	/// The action button associated with this view
	IBOutlet id actionButton;
	
	/// The splits window delegate
	IBOutlet id splitsWindowDelegate;
	
	/// Outlet to the transactions controller; needed to bind the search bar
	IBOutlet id transactionsController;

	/// Outlet to the transactions controller; needed to bind the search bar
	IBOutlet id budgetItemsController;

	/// Outlet to the search field so it can be tied to the right controller
	IBOutlet id searchField;
	
	IBOutlet id	reportController;
	
	// Is this the first time an account is being selected?
	BOOL _firstSelection;
	
	BOOL _rightMouseDown;
}

static const int AccountsMenuNewBinderItem			= 1;
static const int AccountsMenuNewAccountItem			= 2;
static const int AccountsMenuDeleteItem				= 3;

static const int AccountsMenuBudgetMenu				= 100;
static const int AccountsMenuMakeBudgetActiveItem	= 101;
static const int AccountsMenuDuplicateBudgetItem	= 102;

static const int AccountsMenuReconcileItem			= 200;


- (void) setupActionButtonForAccount: (NSManagedObject*) account ofType: (NSString*) type;

- (void) setupSearchBarForAccountType: (NSString*) type;

- (void) setupBankMenuForAccount: (NSManagedObject*) account;

- (IBAction) editAccount: (id) sender;

/**
TODO - DELETE?
- (IBAction) selectAccount: (id) sender;
*/
@end
