////////////////////////////////////////////////////////////////////////////////
//  AccountsSplitViewDelegate.h
////////////////////////////////////////////////////////////////////////////////
///
/// @brief	Controls a viewpoint instance.
///
/// This class controls a viewpoint instance.  It is responsible for managing
/// the account selection changing, as well as setting up all the viewpoint
/// controllers and views as necessary.
///
/// Copyright (c) 2006, 2007 MotiMotion.
///
/// @author	Michael Rutt
///			<a href="mailto:michael@motimotion.com">michael@motimotion.com</a>
///			<a href="http://www.mikerutt.com">http://www.mikerutt.com</a>
///
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>


@interface AccountsSplitViewDelegate : NSObject
{
	/// Outlet to the account list / viewpoint splitview
	IBOutlet NSSplitView*	splitview;
	
	/// Outlet to the viewpoints animation button
	IBOutlet id				vpAnimationButton;
	
	/// Outlet to the accounts controller (observes account changes)
	IBOutlet id				accountsController;

	/// Is the viewpoint collapsed?
	BOOL					collapsed;
	
	/// Are preferences currently being retrieved?
	BOOL					retrievingPreferences;
	
	/// Is the view currently animating?
	BOOL					animating;

	/// The account currently being observed
	NSManagedObject*		observedAccount;
}

////////////////////////////////////////////////////////////////////////////////
/// Toggles visibility of the viewpoints using animation.
////////////////////////////////////////////////////////////////////////////////
- (IBAction) toggleViewPoints: (id) sender;

////////////////////////////////////////////////////////////////////////////////
/// Stores the display preferences for the account list viewpoint (size,
/// collapsed state, and currently displayed viewpoint).
////////////////////////////////////////////////////////////////////////////////
- (void) storePreferences;

////////////////////////////////////////////////////////////////////////////////
/// Stores the display preferences for the account list viewpoint (size,
/// collapsed state, and currently displayed viewpoint).
////////////////////////////////////////////////////////////////////////////////
- (void) storePreferences;

////////////////////////////////////////////////////////////////////////////////
/// YES if the viewpoints are collapsed (hidden); NO if visible.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) collapsed;


- (void) collapseVPWithAnimation: (BOOL) animate;

- (void) expandVPWithAnimation: (BOOL) animate;

- (void) adjustSizesOfVPRect: (NSRect) newVPRect
					listRect: (NSRect) newListRect
					 animate: (BOOL) animate;

@end
