////////////////////////////////////////////////////////////////////////////////
//  BalanceHistoryViewPointController.h
////////////////////////////////////////////////////////////////////////////////
///
/// @brief	Controls a Balance History ViewPoint instance.
///
/// This class controls a balance history viewpoint instance.  It is responsible
/// updating the line chart when the account selection changes or the current
/// account balance changes.
///
/// Copyright (c) 2006, 2007 MotiMotion.
///
/// @author	Michael Rutt
///			<a href="mailto:michael@motimotion.com">michael@motimotion.com</a>
///			<a href="http://www.mikerutt.com">http://www.mikerutt.com</a>
///
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>
#import "ViewPointComponentController.h"

@interface BalanceHistoryViewPointController : ViewPointComponentController
{

}

/// Number of seconds to delay before executing the update thread
static const float DISPLAY_DELAY = 0.5;

// View tags
static const int MIN_VALUE_TAG		= 2;
static const int MAX_VALUE_TAG		= 3;
static const int TIMEFRAME_TEXT_TAG	= 4;


//==============================================================================
// Class methods.
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (NSCalendarDate*) dateOfFirstTransaction;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) setChartForDays: (int) numberOfDays;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) refreshChart: (id) value;

////////////////////////////////////////////////////////////////////////////////
/// Called whenever the user changes the timeframe on the viewpoint.
////////////////////////////////////////////////////////////////////////////////
- (void) timeframeChanged;

////////////////////////////////////////////////////////////////////////////////
/// Called after the view has been made active.
////////////////////////////////////////////////////////////////////////////////
- (void) viewMadeActive;

////////////////////////////////////////////////////////////////////////////////
/// Sets the timeframe label appropriately
////////////////////////////////////////////////////////////////////////////////
- (void) setTimeframeLabel;


//==============================================================================
// Overridden methods.
//==============================================================================

////////////////////////////////////////////////////////////////////////////////
/// Overrides base class.
////////////////////////////////////////////////////////////////////////////////
- (void) registerObservationsForAccount: (NSManagedObject*) account;

////////////////////////////////////////////////////////////////////////////////
/// Overrides base class.
////////////////////////////////////////////////////////////////////////////////
- (void) unregisterObservationsForAccount: (NSManagedObject*) account;

////////////////////////////////////////////////////////////////////////////////
/// Overrides base class.
////////////////////////////////////////////////////////////////////////////////
- (void) updateViewPointForAccount: (NSManagedObject*) account;


@end
