////////////////////////////////////////////////////////////////////////////////
//  BaseFileReader.h
////////////////////////////////////////////////////////////////////////////////
///
/// @brief	Base class for an external file reader.
///
/// The ImportFileReader is the base class for a file importer that is used
/// to import an external financial file containing data into Prospects.  It
/// provides support to the ImportManager for multithreaded importing and the
/// ability to cancel an import in progress.
///
/// Copyright (c) 2006 MotiMotion.
///
/// @author	Michael Rutt
///			<a href="mailto:michael@motimotion.com">michael@motimotion.com</a>
///			<a href="http://www.mikerutt.com">http://www.mikerutt.com</a>
///
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>
#import <MotiFoundation/MotiImportReader.h>


@interface BaseFileReader : MotiImportReader
{
	/// Mutable array of all the non-transaction objects imported by the reader
	NSMutableArray*		_specialImportedObjects;
}

////////////////////////////////////////////////////////////////////////////////
/// Are there unique objects that need importing?
////////////////////////////////////////////////////////////////////////////////
- (BOOL) specialObjectsNeedImporting;

////////////////////////////////////////////////////////////////////////////////
/// The array of special objects to import.
////////////////////////////////////////////////////////////////////////////////
- (NSArray*) specialImportedObjects;

////////////////////////////////////////////////////////////////////////////////
/// YES if if the reader was unable to determine an account to import into;
/// NO if the reader knows where to place the transactions.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) needToSpecifyImportAccount;

@end
