////////////////////////////////////////////////////////////////////////////////
//  BinderController.h
////////////////////////////////////////////////////////////////////////////////
///
/// @brief	Controls the data visible on the Binder screen.
///
/// This class controls the management of the Binder screen - ensuring the data
/// gets updated as needed.
///
/// Copyright (c) 2006, 2007 MotiMotion.
///
/// @author	Michael Rutt
///			<a href="mailto:michael@motimotion.com">michael@motimotion.com</a>
///			<a href="http://www.mikerutt.com">http://www.mikerutt.com</a>
///
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>
#import <MotiFoundation/MotiNumberFormatter.h>


@interface BinderController : NSObject
{
	IBOutlet id				assetsChart;

	IBOutlet id				liabilitiesChart;
	
	IBOutlet id				monthlyBalanceChart;
	
	IBOutlet id				allTransactionsController;
	
	IBOutlet id				binderView;
	
	MotiNumberFormatter*	_amountFormatter;
	NSNumberFormatter*		_percentFormatter;
	
	NSColor*				_assetColor;
	NSColor*				_liabilityColor;
	
	NSString*				_stringPrefix;
	NSString*				_accountNameKey;
	
	NSDecimalNumber*		_balanceToday;
}

static const int ASSETS_LABEL_TAG = 50;
static const int LIABILITIES_LABEL_TAG = 51;
static const int BALANCES_LABEL_TAG = 52;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) updateMonthlyBalancesForBinder: (NSManagedObject*) binder
		  					   accounts: (NSArray*) accounts;

////////////////////////////////////////////////////////////////////////////////
/// Refreshes the data and content on the binder display.
////////////////////////////////////////////////////////////////////////////////
- (void) updateForBinder: (NSManagedObject*) binder;

@end
