//------------------------------------------------------------------------------
// CategorySelectionController.h
//
// Copyright (c) 2006 MotiMotion
// All rights reserved.
//
// Author: Michael Rutt (michael@motimotion.com)
//		   http://blogs.motimotion.com/michael
//------------------------------------------------------------------------------


#import <Cocoa/Cocoa.h>

//------------------------------------------------------------------------------
// Manages the array of category names used for selection in the account
// view.
//------------------------------------------------------------------------------
@interface CategorySelectionController : NSArrayController
{
	/// Prospects color list
	NSColorList*		colorList;
	
	BOOL				_rearranging;
}

//------------------------------------------------------------------------------
// Overrides the base arrangeObjects method to use the selectionSortDescriptors
// and return a sorted array of category names for selection by the user.
//------------------------------------------------------------------------------
//- (NSArray *) arrangeObjects: (NSArray *) objects;

//------------------------------------------------------------------------------
// Returns the sort descriptors that are used by arrangeObjects to sort the
// list of categories appropriately when displaying in the selection list
// in the account view.
//------------------------------------------------------------------------------
//- (NSArray *) selectionSortDescriptors;

////////////////////////////////////////////////////////////////////////////////
/// Returns the next available color key based upon the ones already used
/// for the categories.
////////////////////////////////////////////////////////////////////////////////
- (NSString*) nextAvailableCategoryColorKey;

////////////////////////////////////////////////////////////////////////////////
/// Returns YES if a category exists that is not equal to 'category' and has
/// the same value for the key specified.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) category: (NSManagedObject*) category hasDuplicateValue: (id) value forKey: (NSString*) key;

@end
