////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>
#import "ImportConditionView.h"


// Defines the various tags on the import rule panel that is used to create
// or modify an import rule

/// The name of the import rule
static const int ImportRuleNameTag		= 10;

/// Whether or not the import rule is enabled
static const int ImportRuleEnabledTag   = 11;

/// Whether all or any of the rule conditions apply
static const int ImportRuleApplyTag		= 12;

/// The category to assign the imported transaction
static const int ImportRuleCategoryTag	= 13;

/// The value to place in the purpose field of the imported transaction
static const int ImportRulePurposeTag	= 14;

/// The value to place in the memo tag of the imported transaction
static const int ImportRuleMemoTag		= 15;

/// The cleared/reconciled status to set for the imported transaction
static const int ImportRuleStatusTag	= 16;

////////////////////////////////////////////////////////////////////////////////

@interface ImportRuleSheetController : NSObject
{
	/// The panel containing the data
	IBOutlet id			rulePanel;
	
	/// The conditions NSBox
	IBOutlet id			conditionsBox;
	
	/// The first ImportConditionView
	IBOutlet id			firstConditionView;
	/// The second ImportConditionView
	IBOutlet id			secondConditionView;
	/// The third ImportConditionView
	IBOutlet id			thirdConditionView;
	
	/// The number of conditions currently displayed
	unsigned			numConditionsDisplayed;
	
	/// The conditions NSArray controller
	IBOutlet id			conditionsController;
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (IBAction) addCondition: (id)sender;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (IBAction) deleteCondition: (id)sender;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) moveDataFromCondition: (ImportConditionView*) fromCondition
				   toCondition: (ImportConditionView*) toCondition;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) resizePanelForCondition: (BOOL) addedItem animate: (BOOL) showAnimation;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (IBAction) conditionChanged: (id) sender;

/*
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setDataForCondition: (int) conditionNumber
			conditionElement: (int) element
			   conditionCase: (int) condCase
			  conditionValue: (NSString*) value;
*/

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (NSString*) ruleName;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setRuleName: (NSString*) name;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (int) howToApplyConditions;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setHowToApplyConditions: (int) index;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (NSString*) purpose;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setPurpose: (NSString*) value;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (NSString*) memo;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setMemo: (NSString*) value;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (NSManagedObject*) category;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setCategory: (NSManagedObject*) value;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (int) status;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setStatus: (int) value;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (int) ruleEnabled;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (void) setRuleEnabled: (int) enabled;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
- (ImportConditionView*) conditionView: (int) conditionNumber;

////////////////////////////////////////////////////////////////////////////////
/// Resets the import rule sheet to empty values.
////////////////////////////////////////////////////////////////////////////////
- (void) resetSheet;

////////////////////////////////////////////////////////////////////////////////
/// Returns the number of conditions that have been set and are valid on the
/// import rule sheet.
////////////////////////////////////////////////////////////////////////////////
- (int) validConditions;


@end
