////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////

#import <Cocoa/Cocoa.h>

typedef enum
{
	/// Account subview index of the main outline view
	PAccountSubviewIndex	= 0,
	/// Content subview index of the main outline view
	PContentSubviewIndex	= 1,
	/// Viewpoints subview index of the main outline view
	PViewPointsSubviewIndex	= 2
} SubviewIndexes;

/// Max width of the viewpoint or account list views in terms of percentage of
/// total window width
static const float PMaxSubviewWidthPercentage	= 0.40;
/// Max width of the content view in terms of percentage of total window width
static const float PMaxContentSubviewWidthPercentage	= 0.60;
/// Minimum width in pixels of the account list or viewpoints
static const float PMinSubviewWidthPixels		= 250.0;


@interface MainSplitViewDelegate : NSObject
{
	/// Minimum width of the accounts outline view
	float accountsOutlineMinWidth;
	
	/// Maximum width of the accounts outline view
	float accountsOutlineMaxWidth;
	
	/// Minimum width of the viewpoints view
	float viewPointsMinWidth;

	/// Maximum width of the viewpoints view	
	float viewPointsMaxWidth;
	
	/// Are the viewpoints visible?
	BOOL viewPointsVisible;
	
	/// Last known width of the splitview
	float lastWidth;
	
	/// Last known height of the splitview
	float lastHeight;
	
	BOOL firstResize;
}

////////////////////////////////////////////////////////////////////////////////
/// Returns whether or not the subview is allowed to collapse when the user
/// drags the divider to 1/2 the minimum size.  For this implementation, the
/// answer is always NO.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) splitView: (NSSplitView*) sender canCollapseSubview: (NSView*) subview;

////////////////////////////////////////////////////////////////////////////////
/// Constrains the minimum width of the subview to the left of the divider
// specified by the offset (i.e. left-most divider is offset 0).
////////////////////////////////////////////////////////////////////////////////
- (float) splitView: (NSSplitView*) sender
	constrainMinCoordinate: (float) proposedMin
			   ofSubviewAt: (int) offset;

////////////////////////////////////////////////////////////////////////////////
/// Constrains the maximum width of the subview to the left of the divider
// specified by the offset (i.e. left-most divider is offset 0).
////////////////////////////////////////////////////////////////////////////////
- (float) splitView: (NSSplitView*) sender 
	constrainMaxCoordinate: (float) proposedMax
			   ofSubviewAt: (int) offset;

////////////////////////////////////////////////////////////////////////////////
/// Called after the frame of the splitview has changed.  Allows 
////////////////////////////////////////////////////////////////////////////////
- (void) splitView: (NSSplitView*) sender resizeSubviewsWithOldSize: (NSSize) oldSize;

- (void) makeViewPointsVisible: (BOOL) visible;

@end
