//------------------------------------------------------------------------------
// MotiGradientOutlineView.h
//
// Copyright (c) 2006 MotiMotion
// All rights reserved.
//
// Author: Michael Rutt (michael@motimotion.com)
//		   http://blogs.motimotion.com/michael
//------------------------------------------------------------------------------

#import <Cocoa/Cocoa.h>


@interface MotiGradientOutlineView : NSOutlineView
{
	NSIndexSet *draggedRows;
	
	BOOL usesGradientSelection;
	BOOL selectionGradientIsContiguous;
	BOOL usesDisabledGradientSelectionOnly;
	BOOL hasBreakBetweenGradientSelectedRows;
	
	/// The color of the label font for a selected row in the table
	NSColor*		selectedFontColor;
	
	/// The color of the label font for a deselected row in the table
	NSColor*		unselectedFontColor;
	
	/// The top color of the selected row's background gradient when the
	/// the view is in focus
	NSColor*		selectedInFocusBgTopColor;
	
	/// The bottom color of the selected row's background gradient when the
	/// the view is in focus
	NSColor*		selectedInFocusBgBottomColor;
	
	/// The light color of the selected row's background gradient when the
	/// the view is not in focus
	NSColor*		selectedOutOfFocusBgTopColor;
	
	/// The dark color of the selected row's background gradient when the
	/// the view is not in focus
	NSColor*		selectedOutOfFocusBgBottomColor;
	
	NSRect			_lastHighlightClipRect;
}

//------------------------------------------------------------------------------
// Returns rows being dragged; necessary for determining row hightlight color
// while dragging is taking place.
//------------------------------------------------------------------------------
- (NSIndexSet *)draggedRows;

//------------------------------------------------------------------------------
// Sets where to use gradient selection.
//------------------------------------------------------------------------------
- (void)setUsesGradientSelection:(BOOL)flag;
- (BOOL)usesGradientSelection;

//------------------------------------------------------------------------------
// Sets whether gradient selections should be contiguous across multiple
// rows. (iTunes and Mail don't have this, but I think it looks better.)
//------------------------------------------------------------------------------
- (void)setSelectionGradientIsContiguous:(BOOL)flag;
- (BOOL)selectionGradientIsContiguous;

//------------------------------------------------------------------------------
// Sets whether the selection should always look disabled (grey), even
// when the outline view has the focus (like in Mail) */
//------------------------------------------------------------------------------
- (void)setUsesDisabledGradientSelectionOnly:(BOOL)flag;
- (BOOL)usesDisabledGradientSelectionOnly;

//------------------------------------------------------------------------------
// Sets whether selected rows have a pixel gap between them that is the
// background colour rather than the selection colour
//------------------------------------------------------------------------------
- (void)setHasBreakBetweenGradientSelectedRows:(BOOL)flag;
- (BOOL)hasBreakBetweenGradientSelectedRows;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (NSColor*) selectedFontColor;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) setSelectedFontColor: (NSColor*) color;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (NSColor*) unselectedFontColor;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) setUnselectedFontColor: (NSColor*) color;


////////////////////////////////////////////////////////////////////////////////
/// @note Source: http://www.cocoadev.com/index.pl?RoundedRectangles
////////////////////////////////////////////////////////////////////////////////
/*
+ (NSBezierPath*) bezierPathWithRoundRectInRect: (NSRect) aRect
										 radius: (float) radius;
*/

@end
