//
//  OFXReader.h
//  Prospects
//
//  Created by Michael Rutt on 4/3/07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "BaseFileReader.h"


@interface OFXReader : BaseFileReader
{
	/// The OFX file broken up into an array where each line contains a line of
	/// the file
	NSArray*			_documentData;
	
	/// String contents of the line being parsed
	NSString*			_currentLine;
	
	/// Current line number looking at the _documentData
	int					_lineNo;
	
	/// Points to the OFXDocument managed object being worked on; nil if not
	/// a valid one
	NSManagedObject*	_document;
	
	NSNumberFormatter*	_amountFormatter;
	
	NSDecimalNumberHandler* _handler;
}

- (BOOL) loadFromString: (NSString *) fileString;

////// OFX SPECIFICS //////

////////////////////////////////////////////////////////////////////////////////
/// Returns a date (ignoring the time / timezone) based upon the value passed in
/// to a dt (datetime) field in an OFX tag.
////////////////////////////////////////////////////////////////////////////////
- (NSDate*) dateForDTTag: (NSString*) datetime;

////////////////////////////////////////////////////////////////////////////////
/// Parses the current line into the tag and value as possible.  If line
/// has no data or is not parsable, tag is nil.  If it is a tag only, value
/// is nil.  If it is a tag/value, both have values.
////////////////////////////////////////////////////////////////////////////////
- (void) parseCurrentLineIntoTag: (NSString**) tag value: (NSString**) value;

////////////////////////////////////////////////////////////////////////////////
/// Parses to an endTag (e.g. @"</STATUS>"), placing each value that is found
/// into the object using the tag name in all lowercase as the key.  If a key
/// is specified that is not recognized, it is skipped.  Returns NO if any error
/// occurs.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) parseToTag: (NSString*) endTag usingObject: (NSManagedObject*) object;

////////////////////////////////////////////////////////////////////////////////
/// Parses the OFX header and instantiates the empty OFXDocument.  Returns YES
/// on success and NO on error.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) parseOFXHeader;

////////////////////////////////////////////////////////////////////////////////
/// Parses a sign-on response(SONRS).  Returns YES on success and NO on error.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) parseSignOnResponse;

- (BOOL) parseStatementToClosingTag: (NSString*) closingTag;

- (BOOL) parseTransactionIntoList: (NSMutableSet*) list;

- (BOOL) parseTransactionListIntoStatement: (NSManagedObject*) statement;

// potential base class functions //

////////////////////////////////////////////////////////////////////////////////
/// Retrieves the next line of the file into _currentLine.  Returns YES on 
/// success or NO if end of document reached.
////////////////////////////////////////////////////////////////////////////////
- (BOOL) getNextLine;

////////////////////////////////////////////////////////////////////////////////
/// Erases all the OFXDocuments (which cascade) in the model.
////////////////////////////////////////////////////////////////////////////////
- (void) eraseOFXModelData;

@end
