//
//  RecentTransactionsViewPointController.h
//  Prospects
//
//  Created by Michael Rutt on 12/9/06.
//  Copyright 2006 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "ViewPointComponentController.h"

/// Possible types of data this controller can use to lookup recent transactions;
/// these enumerated values coincide with the index of the menu item in the
/// selectable list in the view 
typedef enum
{
	/// Use the main (top-level) category (i.e. Auto)
	PUseCategoryData	= 0,
	/// Use the payee field
	PUsePayeeData		= 1,
	/// Use the entire category (i.e. Auto:Gas)
	PUseSubCategoryData	= 2
} PRecentTransactionsType;

/// Possible debit types to show in the recent transactions view
typedef enum
{
	/// Show negative transactions (including $0.00) - debits
	PShowSpent			= 0,
	/// Show positive transactions (including $0.00) - deposits
	PShowReceived		= 1
} PRecentTransactionsDebitType;


////////////////////////////////////////////////////////////////////////////////
/// Controls a viewpoint containing the most recent transactions of the same
/// category or payee as the selected transaction.
////////////////////////////////////////////////////////////////////////////////
@interface RecentTransactionsViewPointController : ViewPointComponentController
{
	/// The data that is used to find the recent transactions
	PRecentTransactionsType			dataFilter;
	
	/// The debit type to use when displaying recent transactions
	PRecentTransactionsDebitType	debitType;
	
	/// The value (i.e. "Auto" or "J.Crew") of the data type being displayed
	NSString*						dataFilterValue;
	
	/// The description column of the recent transactions table
	NSTableColumn*					descriptionCol;
	
	/// Set to YES whenever the data needs to be requeried
	BOOL							requeryData;
	
	/// Set to YES whenever data in all accounts should be shown
	BOOL							showAllAccounts;
	
	BOOL							_preparedContent;

	NSManagedObject*				_selectedTransaction;
}

/// Number of seconds to delay when the transaction selection changes before
/// updating the viewpoint
static const float DISPLAY_DELAY = 0.5;
static const int TIMEFRAME_TEXT_TAG = 350;

////////////////////////////////////////////////////////////////////////////////
/// Refreshes the contents and display of the viewpoint.
/// NOTE: value is ignored and needed only for the perform selector call.
////////////////////////////////////////////////////////////////////////////////
- (void) refreshViewPoint: (id) value;

////////////////////////////////////////////////////////////////////////////////
/// Should be called whenever the type of data to filter on has changed.
////////////////////////////////////////////////////////////////////////////////
- (IBAction) dataFilterChanged: (id) sender;

////////////////////////////////////////////////////////////////////////////////
/// Should be called whenever the debit type has changed - sent or received.
////////////////////////////////////////////////////////////////////////////////
- (IBAction) debitTypeChanged: (id) sender;

////////////////////////////////////////////////////////////////////////////////
/// Should be called whenever the time frame has changed.
////////////////////////////////////////////////////////////////////////////////
//- (IBAction) timeframeChanged: (id) sender;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) updateFilterButtonWithTransaction: (NSManagedObject*) transaction;

////////////////////////////////////////////////////////////////////////////////
/// Returns a date to be used in predicate queries based on the timeframe
/// selected in the viewpoint.
////////////////////////////////////////////////////////////////////////////////
- (NSCalendarDate*) startingDateForTimeframe;

- (void) setTimeframeLabel;

////////////////////////////////////////////////////////////////////////////////
/// Called after the view has been made active.
////////////////////////////////////////////////////////////////////////////////
- (void) viewMadeActive;

////////////////////////////////////////////////////////////////////////////////
/// Called by ViewPointController when the transaction selection changes.
////////////////////////////////////////////////////////////////////////////////
- (void) transactionSelected: (NSManagedObject*) transaction;

@end
