//------------------------------------------------------------------------------
// Transaction.h
//
// Copyright (c) 2006 MotiMotion
// All rights reserved.
//
// Author: Michael Rutt (michael@motimotion.com)
//		   http://blogs.motimotion.com/michael
//------------------------------------------------------------------------------

#import <Cocoa/Cocoa.h>


//------------------------------------------------------------------------------
// TODO: class description...
//------------------------------------------------------------------------------
@interface Transaction : NSManagedObject
{
	/// Stores the amount the debit/deposit value changed by when they are updated
	NSDecimalNumber*	amountBeforeChange;
	
	/// The old account for the transaction if it has been changed
	NSManagedObject*	oldAccount;
	
	/// The old category for the transaction if it has been changed
	NSManagedObject*	oldCategory;
	
	/// If the transaction is in a faulting state (being fetched), do not
	/// perform any KVO-related activities even though they are fired!
	BOOL				faulting;
}

//------------------------------------------------------------------------------
// Properly sets the deposit or debit column in the transaction's data depending
// on whether it is a negative or positive transaction amount.
//------------------------------------------------------------------------------
- (void) setAmount: (NSDecimalNumber *) amount;

- (void) setAmountQuietly: (NSDecimalNumber *)amount;

//------------------------------------------------------------------------------
// Returns the amount of the transaction, or 0.0 if none has been specified.
//------------------------------------------------------------------------------
- (NSDecimalNumber *) amount;

//------------------------------------------------------------------------------
// Function to compare this transaction with another transaction to determine
// their order.  Adheres to the selector signature for an NSArray sort
// comparison.
//------------------------------------------------------------------------------ 
- (NSComparisonResult) transactionDateCompare: (Transaction *) transaction;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) validateSplits;

////////////////////////////////////////////////////////////////////////////////
///
////////////////////////////////////////////////////////////////////////////////
- (void) adjustSplitDatesToMatch;

@end
