//------------------------------------------------------------------------------
// TransactionsController.h
//
// Copyright (c) 2006 MotiMotion
// All rights reserved.
//
// Author: Michael Rutt (michael@motimotion.com)
//		   http://blogs.motimotion.com/michael
//------------------------------------------------------------------------------

#import <Cocoa/Cocoa.h>
#import "BankAccount.h"

//------------------------------------------------------------------------------
// Manages the array of transactions use for display in the account view.
//------------------------------------------------------------------------------
@interface TransactionsController : NSArrayController
{
	/// The account list controller that manages the list of accounts and
	/// the currently selected account
	IBOutlet id		accountsController;
	
	/// The category controller that manages the list of categories
	IBOutlet id		categorySelectionController;
	
	/// The controller that manages the split transactions
	IBOutlet id		splitController;
}

//------------------------------------------------------------------------------
// Adds a new BankAccountTransaction to the transactions controller.  Properly
// sets up all relationships based upon currently selected account in the list.
//------------------------------------------------------------------------------
- (IBAction) addBankAccountTransaction: (id)sender;

////////////////////////////////////////////////////////////////////////////////
/// Adds the empty transaction to the specified account.
////////////////////////////////////////////////////////////////////////////////
- (void) addTheEmptyBankAccountTransactionToAccount: (Account*) account;

//------------------------------------------------------------------------------
// Adds a new BankAccountTransaction to the transactions controller based upon
// the data specified.
//------------------------------------------------------------------------------
- (NSManagedObject*) addBankAccountTransactionToAccount: (BankAccount *) account
										   categoryName: (NSString *) categoryName
												  payee: (NSString *) payee
												 amount: (NSDecimalNumber*) amount
												   date: (NSDate *) date;

//------------------------------------------------------------------------------
// Removes a BankAccountTransaction from the transactions controller.  Properly
// cleans up all relationships.
//------------------------------------------------------------------------------
//- (IBAction) removeBankAccountTransaction: (id)sender;

////////////////////////////////////////////////////////////////////////////////
/// Splits the selected transaction.
////////////////////////////////////////////////////////////////////////////////
- (IBAction) splitTransaction: (id) sender;

////////////////////////////////////////////////////////////////////////////////
/// Clears the split for the selected transaction.
////////////////////////////////////////////////////////////////////////////////
- (IBAction) clearSplit: (id) sender;

@end
